@@ -33,6 +33,7 @@ namespace LongoMatch.Store.Templates
 		private byte[] thumbnailBuf;
 		private const int MAX_WIDTH=100;
 		private const int MAX_HEIGHT=100;
+		Version version;
 		
 		public TeamTemplate() {
 			TeamName = Catalog.GetString("Team");
@@ -48,6 +49,11 @@ namespace LongoMatch.Store.Templates
 			set;
 		}
 		
+		public Version Version {
+			get;
+			set;
+		}
+		
 		public Image Shield {
 			get {
 				if(thumbnailBuf != null)
@@ -94,6 +100,7 @@ namespace LongoMatch.Store.Templates
 			Clear();
 			for(int i=1; i<=playersCount; i++)
 				AddDefaultItem(i-1);
+			version = new Version (Constants.DB_MAYOR_VERSION, Constants.DB_MINOR_VERSION);
 		}
 	}
 }
