@@ -49,6 +49,7 @@ namespace LongoMatch.Gui
 		public event NewTagHandler NewTagEvent;
 		public event NewTagStartHandler NewTagStartEvent;
 		public event NewTagStopHandler NewTagStopEvent;
+		public event NewTagCancelHandler NewTagCancelEvent;
 		public event PlaySelectedHandler PlaySelectedEvent;
 		public event NewTagAtFrameHandler NewTagAtFrameEvent;
 		public event TagPlayHandler TagPlayEvent;
@@ -259,6 +260,7 @@ namespace LongoMatch.Gui
 			buttonswidget.NewMarkEvent += EmitNewTag;;
 			buttonswidget.NewMarkStartEvent += EmitNewTagStart;
 			buttonswidget.NewMarkStopEvent += EmitNewTagStop;
+			buttonswidget.NewMarkCancelEvent += EmitNewTagCancel;
 			timeline.NewMarkEvent += EmitNewTagAtFrame;
 
 			/* Connect TimeNodeChanged events */
@@ -543,7 +545,7 @@ namespace LongoMatch.Gui
 			}
 
 			/* Capture project */
-			dialog = new EndCaptureDialog();
+			dialog = new EndCaptureDialog(openedProject.Description.File.FilePath);
 			dialog.TransientFor = (Gtk.Window)this.Toplevel;
 			res = dialog.Run();
 			dialog.Destroy();
@@ -769,6 +771,7 @@ namespace LongoMatch.Gui
 				guTimeline.CurrentFrame = frame;
 			}
 			gameunitstaggerwidget1.CurrentTime = new Time{MSeconds = (int)currentTime};
+			buttonswidget.CurrentTime = new Time{MSeconds = (int)currentTime};
 		}
 		
 		protected virtual void OnUpdate(Version version, string URL) {
@@ -863,9 +866,9 @@ namespace LongoMatch.Gui
 				NewTagEvent(category);
 		}
 
-		private void EmitNewTagStart() {
+		private void EmitNewTagStart(Category category) {
 			if (NewTagStartEvent != null)
-				NewTagStartEvent ();
+				NewTagStartEvent (category);
 		}
 
 		private void EmitNewTagStop(Category category) {
@@ -873,6 +876,11 @@ namespace LongoMatch.Gui
 				NewTagStopEvent (category);
 		}
 		
+		private void EmitNewTagCancel(Category category) {
+			if (NewTagCancelEvent != null)
+				NewTagCancelEvent (category);
+		}
+		
 		private void EmitRenderPlaylist(IPlayList playlist) {
 			if (RenderPlaylistEvent != null)
 				RenderPlaylistEvent(playlist);
