@@ -83,7 +83,6 @@ namespace LongoMatch.Services
 			/* Handle Add/Select/Rate events from other widgets */
 			mainWindow.PlayListNodeAddedEvent += OnPlayListNodeAdded;
 			mainWindow.PlayListNodeSelectedEvent += LoadPlaylistPlay;
-			mainWindow.ApplyRateEvent += (p) => {p.Rate = player.Rate;};
 			mainWindow.RenderPlaylistEvent += OnRenderPlaylistEvent;
 			
 			/* Handle Next/Prev from the player */
@@ -172,20 +171,15 @@ namespace LongoMatch.Services
 		protected virtual void OnRenderPlaylistEvent (IPlayList playlist)
 		{
 			List<EditionJob> jobs = guiToolkit.ConfigureRenderingJob(playlist);
+			if (jobs == null)
+				return;
 			foreach (Job job in jobs)
 				videoRenderer.AddJob(job);
 		}
 		
 		protected virtual void OnPlayListNodeAdded(Play play)
 		{
-			Add(new PlayListPlay {
-				MediaFile = OpenedProject.Description.File,
-				Drawings = play.Drawings,
-				Start = play.Start,
-				Stop = play.Stop,
-				Name = play.Name,
-				Rate = 1.0f,
-			});
+			Add(new PlayListPlay (play, OpenedProject.Description.File, true));
 		}
 		
 		protected virtual void OnSavePlaylist()
