@@ -35,6 +35,7 @@ namespace LongoMatch.Services
 		private Dictionary<Type, ITemplateProvider> dict;
 		private List<PlayerSubCategory> playerSubcatList;
 		private List<TeamSubCategory> teamSubcatList;
+		private List<CoordinatesSubCategory> coordinatesSubcatList;
 		
 		public TemplatesService (string basePath)
 		{
@@ -45,6 +46,7 @@ namespace LongoMatch.Services
 			CheckDefaultTemplates();
 			CreateDefaultPlayerSubCategories();
 			CreateDefaultTeamSubCategories();
+			CreateDefaultCoordinatesSubCategories();
 			
 		}
 		
@@ -76,6 +78,20 @@ namespace LongoMatch.Services
 			subcat.Add(Team.VISITOR);
 			playerSubcatList.Add(subcat);
 		}
+		
+		private void CreateDefaultCoordinatesSubCategories () {
+			CoordinatesSubCategory subcat;
+			
+			coordinatesSubcatList = new List<CoordinatesSubCategory>();
+			
+			/* Position */
+			subcat = new CoordinatesSubCategory {Name=Catalog.GetString("Position"), FastTag=true, NumCoordinates=1};
+			coordinatesSubcatList.Add(subcat);
+
+			/* Trajectory */
+			subcat = new CoordinatesSubCategory {Name=Catalog.GetString("Trajectory"), FastTag=true, NumCoordinates=2};
+			coordinatesSubcatList.Add(subcat);
+		}
 
 		private void CreateDefaultTeamSubCategories () {
 			teamSubcatList = new List<TeamSubCategory>();
@@ -117,6 +133,12 @@ namespace LongoMatch.Services
 				return teamSubcatList;
 			}
 		}
+		
+		public List<CoordinatesSubCategory> CoordinatesSubcategories {
+			get{
+				return coordinatesSubcatList;
+			}
+		}
 	}
 	
 	public class TemplatesProvider<T, U>: ITemplateProvider<T, U> where T: ITemplate<U>
